#[repr(i16)]pub enum TransactionType {
Show 51 variants
Invalid = -1,
Payment = 0,
EscrowCreate = 1,
EscrowFinish = 2,
AccountSet = 3,
EscrowCancel = 4,
SetRegularKey = 5,
NickNameSet = 6,
OfferCreate = 7,
OfferCancel = 8,
Contract = 9,
TicketCreate = 10,
TicketCancel = 11,
SignerListSet = 12,
PaymentChannelCreate = 13,
PaymentChannelFund = 14,
PaymentChannelClaim = 15,
CheckCreate = 16,
CheckCash = 17,
CheckCancel = 18,
DepositPreauth = 19,
TrustSet = 20,
AccountDelete = 21,
SetHook = 22,
NFTokenMint = 25,
NFTokenBurn = 26,
NFTokenCreateOffer = 27,
NFTokenCancelOffer = 28,
NFTokenAcceptOffer = 29,
Clawback = 30,
AMMCreate = 35,
AMMDeposit = 36,
AMMWithdraw = 37,
AMMVote = 38,
AMMBid = 39,
AMMDelete = 40,
XChainCreateClaimID = 41,
XChainCommit = 42,
XChainClaim = 43,
XChainAccountCreateCommit = 44,
XChainAddClaimAttestation = 45,
XChainAddAccountCreateAttestation = 46,
XChainModifyBridge = 47,
XChainCreateBridge = 48,
DIDSet = 49,
DIDDelete = 50,
OracleSet = 51,
OracleDelete = 52,
EnableAmendment = 100,
SetFee = 101,
UNLModify = 102,
}Expand description
The type of any given XRPL transaction.
This enum maps to the transaction type codes used in the XRPL protocol. Each variant corresponds to a specific transaction type with its associated numeric code.
Derived Traits
Debug: Useful for development and debuggingClone: Automatically derived with Copy for consistencyCopy: Efficient for this enum (2 bytes due to#[repr(i16)])PartialEq, Eq: Enable transaction type comparisons
The Copy trait is appropriate here because:
- The enum is only 2 bytes, making copies extremely cheap
- Transaction types are frequently checked and compared
- Implicit copying improves ergonomics
Variants
Invalid = -1
Payment = 0
EscrowCreate = 1
EscrowFinish = 2
AccountSet = 3
EscrowCancel = 4
SetRegularKey = 5
NickNameSet = 6
OfferCreate = 7
OfferCancel = 8
Contract = 9
TicketCreate = 10
TicketCancel = 11
SignerListSet = 12
PaymentChannelCreate = 13
PaymentChannelFund = 14
PaymentChannelClaim = 15
CheckCreate = 16
CheckCash = 17
CheckCancel = 18
DepositPreauth = 19
TrustSet = 20
AccountDelete = 21
SetHook = 22
NFTokenMint = 25
NFTokenBurn = 26
NFTokenCreateOffer = 27
NFTokenCancelOffer = 28
NFTokenAcceptOffer = 29
Clawback = 30
AMMCreate = 35
AMMDeposit = 36
AMMWithdraw = 37
AMMVote = 38
AMMBid = 39
AMMDelete = 40
XChainCreateClaimID = 41
XChainCommit = 42
XChainClaim = 43
XChainAccountCreateCommit = 44
XChainAddClaimAttestation = 45
XChainAddAccountCreateAttestation = 46
XChainModifyBridge = 47
XChainCreateBridge = 48
DIDSet = 49
DIDDelete = 50
OracleSet = 51
OracleDelete = 52
EnableAmendment = 100
SetFee = 101
UNLModify = 102